package com.zehong.web.controller.lpgRegulation;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zehong.common.annotation.Log;
import com.zehong.common.core.controller.BaseController;
import com.zehong.common.core.domain.AjaxResult;
import com.zehong.common.enums.BusinessType;
import com.zehong.system.domain.TLpgDeliveryRecord;
import com.zehong.system.service.ITLpgDeliveryRecordService;
import com.zehong.common.utils.poi.ExcelUtil;
import com.zehong.common.core.page.TableDataInfo;

/**
 * 液化石油配送记录Controller
 * 
 * @author zehong
 * @date 2024-07-22
 */
@RestController
@RequestMapping("/lpg/record")
public class TLpgDeliveryRecordController extends BaseController
{
    @Autowired
    private ITLpgDeliveryRecordService tLpgDeliveryRecordService;

    /**
     * 查询液化石油配送记录列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TLpgDeliveryRecord tLpgDeliveryRecord)
    {
        startPage();
        List<TLpgDeliveryRecord> list = tLpgDeliveryRecordService.selectTLpgDeliveryRecordList(tLpgDeliveryRecord);
        return getDataTable(list);
    }

    /**
     * 导出液化石油配送记录列表
     */
    @Log(title = "液化石油配送记录", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TLpgDeliveryRecord tLpgDeliveryRecord)
    {
        List<TLpgDeliveryRecord> list = tLpgDeliveryRecordService.selectTLpgDeliveryRecordList(tLpgDeliveryRecord);
        ExcelUtil<TLpgDeliveryRecord> util = new ExcelUtil<TLpgDeliveryRecord>(TLpgDeliveryRecord.class);
        return util.exportExcel(list, "液化石油配送记录数据");
    }

    /**
     * 获取液化石油配送记录详细信息
     */
    @GetMapping(value = "/{deliveryRecordId}")
    public AjaxResult getInfo(@PathVariable("deliveryRecordId") Long deliveryRecordId)
    {
        return AjaxResult.success(tLpgDeliveryRecordService.selectTLpgDeliveryRecordById(deliveryRecordId));
    }

    /**
     * 新增液化石油配送记录
     */
    @Log(title = "液化石油配送记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TLpgDeliveryRecord tLpgDeliveryRecord)
    {
        return toAjax(tLpgDeliveryRecordService.insertTLpgDeliveryRecord(tLpgDeliveryRecord));
    }

    /**
     * 修改液化石油配送记录
     */
    @Log(title = "液化石油配送记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TLpgDeliveryRecord tLpgDeliveryRecord)
    {
        return toAjax(tLpgDeliveryRecordService.updateTLpgDeliveryRecord(tLpgDeliveryRecord));
    }

    /**
     * 删除液化石油配送记录
     */
    @Log(title = "液化石油配送记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{deliveryRecordIds}")
    public AjaxResult remove(@PathVariable Long[] deliveryRecordIds)
    {
        return toAjax(tLpgDeliveryRecordService.deleteTLpgDeliveryRecordByIds(deliveryRecordIds));
    }
}
